@@ -36,7 +36,8 @@ function logn()
 
 # if not set, compute from current branch
 if [[ ! ${JOB_BRANCH} ]]; then 
-	JOB_BRANCH=$(git rev-parse --abbrev-ref HEAD); JOB_BRANCH=${JOB_BRANCH//crw-}; JOB_BRANCH=${JOB_BRANCH%%-rhel*}; 
+	JOB_BRANCH=$(git rev-parse --abbrev-ref HEAD); JOB_BRANCH=${JOB_BRANCH//crw-}; JOB_BRANCH=${JOB_BRANCH%%-rhel*}
+	if [[ ${JOB_BRANCH} == "2" ]]; then JOB_BRANCH="2.x"; fi
 fi
 
 UPSTREAM_JOB_NAME="crw-server_${JOB_BRANCH}" # eg., 2.4
